@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2004-2018 ZNC, see the NOTICE file for details.
+ * Copyright (C) 2004-2020 ZNC, see the NOTICE file for details.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -560,8 +560,8 @@ void CClient::UserCommand(CString& sLine) {
             PutStatus(
                 t_f("Network added. Use /znc JumpNetwork {1}, or connect to "
                     "ZNC with username {2} (instead of just {3}) to connect to "
-                    "it.")(sNetwork, m_pUser->GetUserName() + "/" + sNetwork,
-                           m_pUser->GetUserName()));
+                    "it.")(sNetwork, m_pUser->GetUsername() + "/" + sNetwork,
+                           m_pUser->GetUsername()));
         } else {
             PutStatus(t_s("Unable to add that network"));
             PutStatus(sNetworkAddError);
@@ -888,6 +888,7 @@ void CClient::UserCommand(CString& sLine) {
             CTable Table;
             Table.AddColumn(t_s("Name", "listmods"));
             Table.AddColumn(t_s("Arguments", "listmods"));
+            Table.SetStyle(CTable::ListStyle);
             for (const CModule* pMod : Modules) {
                 Table.AddRow();
                 Table.SetCell(t_s("Name", "listmods"), pMod->GetModName());
@@ -898,6 +899,7 @@ void CClient::UserCommand(CString& sLine) {
         if (m_pUser->IsAdmin()) {
             const CModules& GModules = CZNC::Get().GetModules();
 
+            PutStatus("");
             if (!GModules.size()) {
                 PutStatus(t_s("No global modules loaded."));
             } else {
@@ -908,6 +910,7 @@ void CClient::UserCommand(CString& sLine) {
 
         const CModules& UModules = m_pUser->GetModules();
 
+        PutStatus("");
         if (!UModules.size()) {
             PutStatus(t_s("Your user has no modules loaded."));
         } else {
@@ -917,6 +920,7 @@ void CClient::UserCommand(CString& sLine) {
 
         if (m_pNetwork) {
             const CModules& NetworkModules = m_pNetwork->GetModules();
+            PutStatus("");
             if (NetworkModules.empty()) {
                 PutStatus(t_s("This network has no modules loaded."));
             } else {
@@ -937,6 +941,7 @@ void CClient::UserCommand(CString& sLine) {
             CTable Table;
             Table.AddColumn(t_s("Name", "listavailmods"));
             Table.AddColumn(t_s("Description", "listavailmods"));
+            Table.SetStyle(CTable::ListStyle);
 
             for (const CModInfo& Info : ssModules) {
                 Table.AddRow();
@@ -958,6 +963,7 @@ void CClient::UserCommand(CString& sLine) {
             CZNC::Get().GetModules().GetAvailableMods(ssGlobalMods,
                                                       CModInfo::GlobalModule);
 
+            PutStatus("");
             if (ssGlobalMods.empty()) {
                 PutStatus(t_s("No global modules available."));
             } else {
@@ -969,6 +975,7 @@ void CClient::UserCommand(CString& sLine) {
         set<CModInfo> ssUserMods;
         CZNC::Get().GetModules().GetAvailableMods(ssUserMods);
 
+        PutStatus("");
         if (ssUserMods.empty()) {
             PutStatus(t_s("No user modules available."));
         } else {
@@ -980,6 +987,7 @@ void CClient::UserCommand(CString& sLine) {
         CZNC::Get().GetModules().GetAvailableMods(ssNetworkMods,
                                                   CModInfo::NetworkModule);
 
+        PutStatus("");
         if (ssNetworkMods.empty()) {
             PutStatus(t_s("No network modules available."));
         } else {
@@ -1658,6 +1666,7 @@ void CClient::HelpUser(const CString& sFilter) {
     CTable Table;
     Table.AddColumn(t_s("Command", "helpcmd"));
     Table.AddColumn(t_s("Description", "helpcmd"));
+    Table.SetStyle(CTable::ListStyle);
 
     if (sFilter.empty()) {
         PutStatus(
@@ -1670,7 +1679,8 @@ void CClient::HelpUser(const CString& sFilter) {
         if (sFilter.empty() || sCmd.StartsWith(sFilter) ||
             sCmd.AsLower().WildCmp(sFilter.AsLower())) {
             Table.AddRow();
-            Table.SetCell(t_s("Command", "helpcmd"), sCmd + " " + sArgs);
+            Table.SetCell(t_s("Command", "helpcmd"),
+                          sCmd + (sArgs.empty() ? "" : " ") + sArgs);
             Table.SetCell(t_s("Description", "helpcmd"), sDesc);
         }
     };
